==> kadaster-gds2-2.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragenresultaat/v20170401/BestandenlijstOpvragenResultaatType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401.BestandenLijstType;
import nl.kadaster.schemas.gds2.imgds.baseurl.v20170401.BaseURLSetType;
import nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922.ProcesVerwerking;


/**
 * De opgevraagde bestandenlijst met afgifte gegevens
 * 				voor bestanden. De lijst bevat die afgiftes die voldoen
 * 				aan de gebruikte selectiegegevens. Indien er geen afgiftes voldoen
 * 				aan deze selectie gegevens, dan is er geen bestandenlijst aanwezig
 * 				in het resultaat. 
 * 
 * &lt;p&gt;Java class for BestandenlijstOpvragenResultaatType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="BestandenlijstOpvragenResultaatType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerking"/&amp;gt;
 *         &amp;lt;element name="klantAfgiftenummerMax" type="{http://www.w3.org/2001/XMLSchema}int"/&amp;gt;
 *         &amp;lt;element name="afgifteAantalInLijst" type="{http://www.w3.org/2001/XMLSchema}int"/&amp;gt;
 *         &amp;lt;element name="BaseURLSet" type="{http://www.kadaster.nl/schemas/gds2/imgds/baseurl/v20170401}BaseURLSetType" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401}BestandenLijst" minOccurs="0"/&amp;gt;
 *         &amp;lt;element name="meerAfgiftesbeschikbaar" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenlijstOpvragenResultaatType", propOrder = {
    "procesVerwerking",
    "klantAfgiftenummerMax",
    "afgifteAantalInLijst",
    "baseURLSet",
    "bestandenLijst",
    "meerAfgiftesbeschikbaar"
})
public class BestandenlijstOpvragenResultaatType {

    @XmlElement(name = "ProcesVerwerking", namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", required = true)
    protected ProcesVerwerking procesVerwerking;
    protected int klantAfgiftenummerMax;
    protected int afgifteAantalInLijst;
    @XmlElement(name = "BaseURLSet")
    protected BaseURLSetType baseURLSet;
    @XmlElement(name = "BestandenLijst", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401")
    protected BestandenLijstType bestandenLijst;
    @XmlElement(defaultValue = "true")
    protected Boolean meerAfgiftesbeschikbaar;

    /**
     * Gets the value of the procesVerwerking property.
     * 
     * @return
     *     possible object is
     *     {@link ProcesVerwerking }
     *     
     */
    public ProcesVerwerking getProcesVerwerking() {
        return procesVerwerking;
    }

    /**
     * Sets the value of the procesVerwerking property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProcesVerwerking }
     *     
     */
    public void setProcesVerwerking(ProcesVerwerking value) {
        this.procesVerwerking = value;
    }

    /**
     * Gets the value of the klantAfgiftenummerMax property.
     * 
     */
    public int getKlantAfgiftenummerMax() {
        return klantAfgiftenummerMax;
    }

    /**
     * Sets the value of the klantAfgiftenummerMax property.
     * 
     */
    public void setKlantAfgiftenummerMax(int value) {
        this.klantAfgiftenummerMax = value;
    }

    /**
     * Gets the value of the afgifteAantalInLijst property.
     * 
     */
    public int getAfgifteAantalInLijst() {
        return afgifteAantalInLijst;
    }

    /**
     * Sets the value of the afgifteAantalInLijst property.
     * 
     */
    public void setAfgifteAantalInLijst(int value) {
        this.afgifteAantalInLijst = value;
    }

    /**
     * Gets the value of the baseURLSet property.
     * 
     * @return
     *     possible object is
     *     {@link BaseURLSetType }
     *     
     */
    public BaseURLSetType getBaseURLSet() {
        return baseURLSet;
    }

    /**
     * Sets the value of the baseURLSet property.
     * 
     * @param value
     *     allowed object is
     *     {@link BaseURLSetType }
     *     
     */
    public void setBaseURLSet(BaseURLSetType value) {
        this.baseURLSet = value;
    }

    /**
     * Gets the value of the bestandenLijst property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenLijstType }
     *     
     */
    public BestandenLijstType getBestandenLijst() {
        return bestandenLijst;
    }

    /**
     * Sets the value of the bestandenLijst property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenLijstType }
     *     
     */
    public void setBestandenLijst(BestandenLijstType value) {
        this.bestandenLijst = value;
    }

    /**
     * Gets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isMeerAfgiftesbeschikbaar() {
        return meerAfgiftesbeschikbaar;
    }

    /**
     * Sets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMeerAfgiftesbeschikbaar(Boolean value) {
        this.meerAfgiftesbeschikbaar = value;
    }

}

==> kadaster-gds2-4.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragenresultaat/v20170401/BestandenlijstOpvragenResultaatType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.v20170401;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401.BestandenLijstType;
import nl.kadaster.schemas.gds2.imgds.baseurl.v20170401.BaseURLSetType;
import nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922.ProcesVerwerking;


/**
 * De opgevraagde bestandenlijst met afgifte gegevens
 * 				voor bestanden. De lijst bevat die afgiftes die voldoen
 * 				aan de gebruikte selectiegegevens. Indien er geen afgiftes voldoen
 * 				aan deze selectie gegevens, dan is er geen bestandenlijst aanwezig
 * 				in het resultaat. 
 * 
 * <p>Java class for BestandenlijstOpvragenResultaatType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandenlijstOpvragenResultaatType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerking"/&gt;
 *         &lt;element name="klantAfgiftenummerMax" type="{http://www.w3.org/2001/XMLSchema}int"/&gt;
 *         &lt;element name="afgifteAantalInLijst" type="{http://www.w3.org/2001/XMLSchema}int"/&gt;
 *         &lt;element name="BaseURLSet" type="{http://www.kadaster.nl/schemas/gds2/imgds/baseurl/v20170401}BaseURLSetType" minOccurs="0"/&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401}BestandenLijst" minOccurs="0"/&gt;
 *         &lt;element name="meerAfgiftesbeschikbaar" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenlijstOpvragenResultaatType", propOrder = {
    "procesVerwerking",
    "klantAfgiftenummerMax",
    "afgifteAantalInLijst",
    "baseURLSet",
    "bestandenLijst",
    "meerAfgiftesbeschikbaar"
})
public class BestandenlijstOpvragenResultaatType {

    @XmlElement(name = "ProcesVerwerking", namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", required = true)
    protected ProcesVerwerking procesVerwerking;
    protected int klantAfgiftenummerMax;
    protected int afgifteAantalInLijst;
    @XmlElement(name = "BaseURLSet")
    protected BaseURLSetType baseURLSet;
    @XmlElement(name = "BestandenLijst", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401")
    protected BestandenLijstType bestandenLijst;
    @XmlElement(defaultValue = "true")
    protected Boolean meerAfgiftesbeschikbaar;

    /**
     * Gets the value of the procesVerwerking property.
     * 
     * @return
     *     possible object is
     *     {@link ProcesVerwerking }
     *     
     */
    public ProcesVerwerking getProcesVerwerking() {
        return procesVerwerking;
    }

    /**
     * Sets the value of the procesVerwerking property.
     * 
     * @param value
     *     allowed object is
     *     {@link ProcesVerwerking }
     *     
     */
    public void setProcesVerwerking(ProcesVerwerking value) {
        this.procesVerwerking = value;
    }

    /**
     * Gets the value of the klantAfgiftenummerMax property.
     * 
     */
    public int getKlantAfgiftenummerMax() {
        return klantAfgiftenummerMax;
    }

    /**
     * Sets the value of the klantAfgiftenummerMax property.
     * 
     */
    public void setKlantAfgiftenummerMax(int value) {
        this.klantAfgiftenummerMax = value;
    }

    /**
     * Gets the value of the afgifteAantalInLijst property.
     * 
     */
    public int getAfgifteAantalInLijst() {
        return afgifteAantalInLijst;
    }

    /**
     * Sets the value of the afgifteAantalInLijst property.
     * 
     */
    public void setAfgifteAantalInLijst(int value) {
        this.afgifteAantalInLijst = value;
    }

    /**
     * Gets the value of the baseURLSet property.
     * 
     * @return
     *     possible object is
     *     {@link BaseURLSetType }
     *     
     */
    public BaseURLSetType getBaseURLSet() {
        return baseURLSet;
    }

    /**
     * Sets the value of the baseURLSet property.
     * 
     * @param value
     *     allowed object is
     *     {@link BaseURLSetType }
     *     
     */
    public void setBaseURLSet(BaseURLSetType value) {
        this.baseURLSet = value;
    }

    /**
     * Gets the value of the bestandenLijst property.
     * 
     * @return
     *     possible object is
     *     {@link BestandenLijstType }
     *     
     */
    public BestandenLijstType getBestandenLijst() {
        return bestandenLijst;
    }

    /**
     * Sets the value of the bestandenLijst property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandenLijstType }
     *     
     */
    public void setBestandenLijst(BestandenLijstType value) {
        this.bestandenLijst = value;
    }

    /**
     * Gets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isMeerAfgiftesbeschikbaar() {
        return meerAfgiftesbeschikbaar;
    }

    /**
     * Sets the value of the meerAfgiftesbeschikbaar property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMeerAfgiftesbeschikbaar(Boolean value) {
        this.meerAfgiftesbeschikbaar = value;
    }

}
